@@ -1,4 +1,4 @@
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, asdict
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
@@ -49,6 +49,9 @@ class IBridge(ABC):
     def jwtVerify(self,token,privateKey,algorithm):
         pass
     @abstractmethod
+    def jwtDecode(self,token):
+        pass
+    @abstractmethod
     def getSystemTime(self):
         pass
     @abstractmethod
