@@ -76,6 +76,8 @@ class Bridge(IBridge):
             }, privateKey, algorithm)
     def jwtVerify(self,token,privateKey,algorithm):
         return jwt.decode(token, privateKey, algorithm)
+    def jwtDecode(self,token):
+        return jwt.decode(token, options={"verify_signature": False})
     def getSystemTime(self):
         return int(time.time())
     def log(self,logAction):
