@@ -1,4 +1,4 @@
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, asdict
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
@@ -136,23 +136,25 @@ class State(IState):
         return result
     
     def reprJSON(self):
-        dict = {}
+        result = {}
+        dict = asdict(self)
         keywordsMap = {"from_":"from","del_":"del","import_":"import","type_":"type"}
-        for key in self.__dict__:
-            val = self.__dict__[key]
+        for key in dict:
+            val = getattr(self, key)
 
-            if type(val) is list:
-                parsedList = []
-                for i in val:
-                    if hasattr(i,'reprJSON'):
-                        parsedList.append(i.reprJSON())
-                    else:
-                        parsedList.append(i)
-                val = parsedList
+            if val is not None:
+                if type(val) is list:
+                    parsedList = []
+                    for i in val:
+                        if hasattr(i,'reprJSON'):
+                            parsedList.append(i.reprJSON())
+                        else:
+                            parsedList.append(i)
+                    val = parsedList
 
-            if hasattr(val,'reprJSON'):
-                val = val.reprJSON()
-            if key in keywordsMap:
-                key = keywordsMap[key]
-            dict.__setitem__(key.replace('_hyphen_', '-'), val)
-        return dict
+                if hasattr(val,'reprJSON'):
+                    val = val.reprJSON()
+                if key in keywordsMap:
+                    key = keywordsMap[key]
+                result.__setitem__(key.replace('_hyphen_', '-'), val)
+        return result
